@@ -80,7 +80,7 @@ install() {
 		lsb_dist='redhat'
 	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/SuSE-release ]; then
-		lsb_dist='suse'
+		lsb_dist='sles'
 	fi
 	if [ -z "$lsb_dist" ] && [ -r /etc/system-release ]; then
 		os=`cat /etc/system-release | awk -F ' ' {'print $1'}`
@@ -121,7 +121,7 @@ install() {
 			return
 			;;
 
-		suse)
+		sles)
 			log_info "SuSE dist detected"
 
 			log_info "Downloading systemd service file"
@@ -205,7 +205,7 @@ start() {
 			return
 			;;
 
-		suse)
+		sles)
 			log_info "SuSE dist detected"
 			/bin/systemctl daemon-reload
 			/bin/systemctl restart spotinst-agent
@@ -266,6 +266,10 @@ log() {
   local readonly message="$@"
   echo -e "${timestamp} [${log_level}] ${message}"
 }
+log_info "Installation of the Spot Agent is governed by NetApp’s end user license agreement (“EULA”), which can be found at:
+          https://www.netapp.com/how-to-buy/sales-terms-and-conditions/
+          By installing the Spot Agent, you accept and approve the EULA."
+
 log_info "Validating before install..."
 validate
 
